@@ -1,9 +1,8 @@
 use crate::Contract;
 
+pub use ethers_core::abi::AbiError;
 use ethers_core::{
-    abi::{
-        Abi, Detokenize, Error, Event, Function, FunctionExt, InvalidOutputType, RawLog, Tokenize,
-    },
+    abi::{Abi, Detokenize, Error, Event, Function, FunctionExt, RawLog, Tokenize},
     types::{Address, Bytes, Selector, H256},
 };
 use ethers_providers::Middleware;
@@ -14,21 +13,6 @@ use std::{
     hash::Hash,
     sync::Arc,
 };
-use thiserror::Error;
-
-#[derive(Error, Debug)]
-pub enum AbiError {
-    /// Thrown when the ABI decoding fails
-    #[error(transparent)]
-    DecodingError(#[from] ethers_core::abi::Error),
-
-    /// Thrown when detokenizing an argument
-    #[error(transparent)]
-    DetokenizationError(#[from] InvalidOutputType),
-
-    #[error("missing or wrong function selector")]
-    WrongSelector,
-}
 
 /// A reduced form of `Contract` which just takes the `abi` and produces
 /// ABI encoded data for its functions.
@@ -141,10 +125,7 @@ pub(crate) fn decode_event<D: Detokenize>(
     data: Bytes,
 ) -> Result<D, AbiError> {
     let tokens = event
-        .parse_log(RawLog {
-            topics,
-            data: data.to_vec(),
-        })?
+        .parse_log(RawLog { topics, data: data.to_vec() })?
         .params
         .into_iter()
         .map(|param| param.value)
@@ -167,7 +148,7 @@ pub fn decode_function_data<D: Detokenize, T: AsRef<[u8]>>(
     let bytes = bytes.as_ref();
     let tokens = if is_input {
         if bytes.len() < 4 || bytes[..4] != function.selector() {
-            return Err(AbiError::WrongSelector);
+            return Err(AbiError::WrongSelector)
         }
         function.decode_input(&bytes[4..])?
     } else {
@@ -210,9 +191,7 @@ mod tests {
             "function approve(address _spender, uint256 value) external view returns (bool, bool)"
         ]).unwrap());
 
-        let spender = "7a250d5630b4cf539739df2c5dacb4c659f2488d"
-            .parse::<Address>()
-            .unwrap();
+        let spender = "7a250d5630b4cf539739df2c5dacb4c659f2488d".parse::<Address>().unwrap();
         let amount = U256::MAX;
 
         let encoded = abi.encode("approve", (spender, amount)).unwrap();
@@ -249,17 +228,7 @@ mod tests {
         let (owner, spender, value): (Address, Address, U256) =
             abi.decode_event("Approval", topics, data).unwrap();
         assert_eq!(value, U256::MAX);
-        assert_eq!(
-            owner,
-            "e4e60fdf9bf188fa57b7a5022230363d5bd56d08"
-                .parse::<Address>()
-                .unwrap()
-        );
-        assert_eq!(
-            spender,
-            "7a250d5630b4cf539739df2c5dacb4c659f2488d"
-                .parse::<Address>()
-                .unwrap()
-        );
+        assert_eq!(owner, "e4e60fdf9bf188fa57b7a5022230363d5bd56d08".parse::<Address>().unwrap());
+        assert_eq!(spender, "7a250d5630b4cf539739df2c5dacb4c659f2488d".parse::<Address>().unwrap());
     }
 }
